import { Construct } from "@aws-cdk/core";
import { IDependable } from "@aws-cdk/core/lib/dependency";
import { Policy } from "./policy";
/**
 * @stability stable
 */
export interface IPolicyAttachmentTarget extends IDependable {
    /**
     * @stability stable
     */
    identifier(): string;
}
/**
 * @stability stable
 */
export interface PolicyAttachmentProps {
    /**
     * The root, OU, or account that you want to attach the policy to.
     *
     * @stability stable
     */
    readonly target: IPolicyAttachmentTarget;
    /**
     * The policy that you want to attach to the target.
     *
     * @stability stable
     */
    readonly policy: Policy;
}
/**
 * Attaches a policy to a root, an organizational unit (OU), or an individual account.
 *
 * How the policy affects accounts depends on the type of policy. Refer to the AWS Organizations User Guide for information about each policy type:
 *
 * @stability stable
 */
export declare class PolicyAttachment extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: PolicyAttachmentProps);
}
